@@ -6,7 +6,7 @@ use Mojo::JSON;
 use Mojo::Util 'deprecated';
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '1.13';
+our $VERSION = '1.14';
 
 sub EXCEPTION {
   +{json => {errors => [{message => 'Internal server error.', path => '/'}]}, status => 500};
@@ -27,8 +27,9 @@ has _validator => sub { JSON::Validator::OpenAPI::Mojolicious->new; };
 sub register {
   my ($self, $app, $config) = @_;
 
+  $self->_validator->coerce($config->{coerce} // 1);
   $self->_validator->load_and_validate_schema(
-    $config->{url},
+    $config->{url} || $config->{spec},
     {
       allow_invalid_ref  => $config->{allow_invalid_ref},
       version_from_class => $config->{version_from_class} // ref $app,
@@ -36,11 +37,12 @@ sub register {
   );
 
   unless ($app->defaults->{'openapi.base_paths'}) {
-    $app->helper('openapi.validate'        => \&_validate);
-    $app->helper('openapi.valid_input'     => sub { _validate($_[0]) ? undef : $_[0] });
-    $app->helper('openapi.spec'            => \&_helper_spec);
-    $app->helper('reply.openapi'           => \&_reply);
     $app->helper('openapi.not_implemented' => \&NOT_IMPLEMENTED);
+    $app->helper('openapi.render_spec'     => \&_reply_spec);
+    $app->helper('openapi.spec'            => \&_helper_spec);
+    $app->helper('openapi.valid_input'     => sub { _validate($_[0]) ? undef : $_[0] });
+    $app->helper('openapi.validate'        => \&_validate);
+    $app->helper('reply.openapi'           => \&_reply);
     $app->hook(before_render => \&_before_render);
     $app->renderer->add_handler(openapi => \&_render);
     push @{$app->renderer->classes}, __PACKAGE__;
@@ -68,7 +70,7 @@ sub _add_routes {
   push @{$app->defaults->{'openapi.base_paths'}}, $base_path;
   $route->to({handler => 'openapi', 'openapi.api_spec' => $api_spec, 'openapi.object' => $self});
 
-  my $spec_route = $route->get->to(cb => \&_reply_spec);
+  my $spec_route = $route->get->to(cb => sub { shift->openapi->render_spec });
   if (my $spec_route_name = $config->{spec_route_name} || $api_spec->get('/x-mojo-name')) {
     $spec_route->name($spec_route_name);
     $route_prefix = "$spec_route_name.";
@@ -367,6 +369,18 @@ be relative to the current operation. Example:
     }
   }
 
+=head2 openapi.render_spec
+
+  $c = $c->openapi->render_spec;
+
+Used to render the specification as either "html" or "json". Set the
+L<Mojolicious/stash> variable "format" to change the format to render.
+
+This helper is called by default, when accessing the "basePath" resource.
+
+The "html" rendering needs improvement. Any help or feedback is much
+appreciated.
+
 =head2 openapi.validate
 
   @errors = $c->openapi->validate;
@@ -495,6 +509,9 @@ the top level.
 See L<JSON::Validator/schema> for the different C<url> formats that is
 accepted.
 
+C<spec> is an alias for "url", which might make more sense if your
+specification is written in perl, instead of JSON or YAML.
+
 =item * version_from_class
 
 Can be used to overriden C</info/version> in the API specification, from the
